@@ -973,10 +973,10 @@ gnomecard_setup(GtkWidget *widget, gpointer data)
 			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
 	
 	/* add add/remove buttons in center */
-	edit->addButton = gtk_button_new_with_label("Add");
-	delButton = gtk_button_new_with_label("Remove");
-	upButton = gtk_button_new_with_label("Move Up");
-	dnButton = gtk_button_new_with_label("Move Dn");
+	edit->addButton = gtk_button_new_with_label(_("Add"));
+	delButton = gtk_button_new_with_label(_("Remove"));
+	upButton = gtk_button_new_with_label(_("Move Up"));
+	dnButton = gtk_button_new_with_label(_("Move Dn"));
 
 	align = gtk_alignment_new(0.0, 0.5, 0, 0);
 	vbox2 = gtk_vbox_new(TRUE, 0);
@@ -992,7 +992,7 @@ gnomecard_setup(GtkWidget *widget, gpointer data)
 	for (l=edit->allHdrs, i=0; l; l=l->next, i++) {
 	    const gchar *rowtxt[2];
 
-	    rowtxt[0] = ((ColumnHeader *)(l->data))->colname;
+	    rowtxt[0] = _(((ColumnHeader *)(l->data))->colname);
 	    rowtxt[1] = NULL;
 
 	    gtk_clist_append(GTK_CLIST(edit->srcList), rowtxt);
