@@ -264,7 +264,7 @@ extern int gnomecard_destroy_cards(void)
     if (gnomecard_cards_blocked()) {
 	GtkWidget *w;
 	
-	w = gnome_message_box_new("There are cards which are currently being modified.\nFinish any pending modifications and try again.",
+	w = gnome_message_box_new(_("There are cards which are currently being modified.\nFinish any pending modifications and try again."),
 				  GNOME_MESSAGE_BOX_ERROR,
 				  GNOME_STOCK_BUTTON_OK, NULL);
 	GTK_WINDOW(w)->position = GTK_WIN_POS_MOUSE;
@@ -276,12 +276,8 @@ extern int gnomecard_destroy_cards(void)
     if (gnomecard_changed) {
 	GtkWidget *w;
 	char *msg;
-	char *tmp = N_(" changed. Save?");
-	int len;
 	
-	len = strlen(tmp) + strlen(gnomecard_fname) + 1;
-	msg = g_malloc(len);
-	snprintf(msg, len, "%s%s", gnomecard_fname, tmp);
+	msg= g_strconcat (gnomecard_fname, _(" changed. Save?"), NULL);
 	
 	w = gnome_message_box_new(msg,
 				  GNOME_MESSAGE_BOX_QUESTION,
@@ -769,6 +765,8 @@ int main (int argc, char *argv[])
 	PortableServer_POA poa;
 	PortableServer_POAManager pm;
 	gchar *ior;
+
+        bindtextdomain(PACKAGE, GNOMELOCALEDIR);
 	textdomain(PACKAGE);
 
 	CORBA_exception_init(&ev);
